/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Download Sort.
 *
 * The Initial Developer of the Original Code is
 * Devon Jensen.
 *
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Devon Jensen <velcrospud@hotmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var RDFC = '@mozilla.org/rdf/container;1';
RDFC = Components.classes[RDFC].createInstance();
RDFC = RDFC.QueryInterface(Components.interfaces.nsIRDFContainer);

var RDFCUtils = '@mozilla.org/rdf/container-utils;1';
RDFCUtils = Components.classes[RDFCUtils].getService();
RDFCUtils = RDFCUtils.QueryInterface(Components.interfaces.nsIRDFContainerUtils);

var RDF = '@mozilla.org/rdf/rdf-service;1';
RDF = Components.classes[RDF].getService();
RDF = RDF.QueryInterface(Components.interfaces.nsIRDFService);
	
var df_ds;

//var aConsoleService = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);

function init() {
	
	// Initialize datasource, gets created if its not there
	var gIOService = Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService);
	var profile = Components.classes["@mozilla.org/profile/manager;1"].getService(Components.interfaces.nsIProfileInternal);
	var gProfileDirURL = gIOService.newFileURI(profile.getProfileDir(profile.currentProfile));
	
	var rootnode=RDF.GetResource("NC:ExtensionRoot");
	df_datasource = RDF.GetDataSourceBlocking("file://" + gProfileDirURL.path + "downsort.rdf");
	
	
	df_ds = new RDFDataSource("file://" + gProfileDirURL.path + "downsort.rdf");  // Wrapper for RDF operations
	//var node = df_ds.getNode("NC:ExtensionRoot");
	
	var listelem = document.getElementById("extList");
	listelem.database.AddDataSource(df_datasource);
	listelem.builder.rebuild();
	
	var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
	var checkbox = document.getElementById("playSound");
    checkbox.checked = pref.getBoolPref(checkbox.getAttribute("prefstring"));
    checkbox = document.getElementById("showFile");
    checkbox.checked = pref.getBoolPref(checkbox.getAttribute("prefstring"));
}

function addToList() {
	
	var node = df_ds.getNode("NC:ExtensionRoot");
	var childName = "NC:ExtensionRoot:" + document.getElementById("enterExt").value.toLowerCase();
	
	if (childName != "NC:ExtensionRoot:") {   // Don't want a blank extension
	
		var child = df_ds.getNode(childName);
		child = node.addChild(child);
		
		child.addTargetOnce("http://home.netscape.com/NC-rdf#ext",document.getElementById("enterExt").value);
		child.addTargetOnce("http://home.netscape.com/NC-rdf#location",document.getElementById("enterLoc").value);
		child.addTargetOnce("http://home.netscape.com/NC-rdf#action", document.getElementById("selectGroup").selectedItem.id);
		df_ds.save();
		
		// rebuild so it alpha sorts correctly, and select it in the list 
		var listelem = document.getElementById("extList");
		listelem.builder.rebuild();
		//listelem.ensureElementIsVisible(newelem); // doesn't work for some reason
		var newelem = document.getElementById(childName);
		listelem.selectItem(newelem);
		
	}
}

function clearFields() {
	document.getElementById("enterExt").value = "";
	document.getElementById("enterLoc").value = "";
	document.getElementById("selectGroup").selectedItem = document.getElementById("selectPrompt");
	document.getElementById("extList").clearSelection();
}

function removeFromList() {
	var listelem = document.getElementById("extList");
	var itemtoremove = listelem.selectedItem;
	var newselection = listelem.getPreviousItem(itemtoremove, 1);
	var child = df_ds.getNode(itemtoremove.id);
	df_ds.deleteRecursive(child);
	df_ds.save();
	clearFields();
	listelem.selectItem(newselection);
}

function boxfocus() {
	document.getElementById("extList").clearSelection();
	//aConsoleService.logStringMessage("focus");
	
}

function boxblur() {
	//aConsoleService.logStringMessage("blur");
	
	
}

function selectList() {
	var currItem = document.getElementById("extList").selectedItem;
	document.getElementById("enterExt").value = currItem.label;
	document.getElementById("enterLoc").value = currItem.getAttribute("location");
	document.getElementById("selectGroup").selectedItem = document.getElementById(currItem.value);
}

function selectFolder() {
	
	const nsIFilePicker = Components.interfaces.nsIFilePicker;
	const nsILocalFile = Components.interfaces.nsILocalFile;
	var fp = Components.classes["@mozilla.org/filepicker;1"]
	                 .createInstance(nsIFilePicker);
	//var pref = Components.classes["@mozilla.org/preferences-service;1"]
	//                 .getService(Components.interfaces.nsIPrefBranch);
	
	fp.init(window, "Select Download Directory:", nsIFilePicker.modeGetFolder);
	
// displayDirectory doesn't work for some reason
/*	try 
	{
	var initialDir = document.getElementById("enterLoc").value;
	
	var lfContractID = "@mozilla.org/file/local;1";
	var lfIID = Components.interfaces.nsILocalFile;
	var lf = Components.classes[lfContractID].createInstance(lfIID);
	lf.initWithPath(initialDir);
	
	aConsoleService.logStringMessage(lf.path);
	
	if (lf)
	  fp.displayDirectory = lf;
	}
	catch (ex)
	{
	// ignore exception: file picker will open at default location
	}
*/

	fp.appendFilters(nsIFilePicker.filterAll);
	var ret = fp.show();
	
	var folderField = document.getElementById("enterLoc");
	if (ret == nsIFilePicker.returnOK) {
		var localFile = fp.file.QueryInterface(nsILocalFile);
		var viewable = fp.file.path;
		folderField.value = viewable;
	}
	else if (ret == nsIFilePicker.returnCancel) {
		
	}
}

function saveSettings() {
	
	var pref = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
	var checkbox = document.getElementById("playSound");
    pref.setBoolPref(checkbox.getAttribute("prefstring"), checkbox.checked);
	checkbox = document.getElementById("showFile");
    pref.setBoolPref(checkbox.getAttribute("prefstring"), checkbox.checked);
	
}